==> nextcloud-20.0.8p0.tgz: nextcloud/apps/password_policy/l10n/da.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Kodeordet er i blandt de 1.000.000 mest almindelige kodeord. Vælg venligst et andet.",
    "Password is present in compromised password list. Please choose a different password." : "Adgangskoden findes i liste over kompromitterede adgangskoder. Vælg en anden adgangsode.",
    "Password needs to be at least %s characters long" : "Kodeord skal mindst være %s tegn lang",
    "Password needs to contain at least one numeric character." : "Kodeord skal mindst indeholde et tal.",
    "Password needs to contain at least one special character." : "Kodeord skal indeholde mindst et special tegn.",
    "Password needs to contain at least one lower and one upper case character." : "Kodeord skal mindst indeholde et lille bogstav og et stort bogstav ",
    "Password policy" : "Kodeord politik",
    "Allows admins to configure a password policy" : "Tillad en administrator at fastsætte en politik for adgsngskoder",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Tillad en administrator af fastsætte krav til adgangskoder, f.eks. at sætte en mindstelængde",
    "Forbid common passwords" : "Forbyd almindelige kodeord",
    "Enforce upper and lower case characters" : "Tving små og store bogstaver",
    "Enforce numeric characters" : "Tving tal",
    "Enforce special characters" : "Tving special tegn",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Kontroller adgangskoden op imod listen over kompromitterede adgangskoder i haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Dette check danner et krypteret kendetegn af adgangskoden og sender de første 4 tegn af dette kendetegn til haveibeenpwned.com's API for at modtage en liste med alle kendetegn, der starter med disse tegn. Derefter checker det, om adgsngskodekendetegnet findes i Nextclud-installationen.",
    "Minimal length" : "Minimums længde"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-22.2.6.tgz: nextcloud/apps/password_policy/l10n/da.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password must not have been used recently before." : "Adgangskoden må ikke være benyttet for nyligt.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Kodeordet er i blandt de 1.000.000 mest almindelige kodeord. Vælg venligst et andet.",
    "Password is present in compromised password list. Please choose a different password." : "Adgangskoden findes i liste over kompromitterede adgangskoder. Vælg en anden adgangsode.",
    "Password needs to be at least %s characters long." : "Adgangskoden skal være mindst %s karakterer lang.",
    "Password needs to contain at least one numeric character." : "Kodeord skal mindst indeholde et tal.",
    "Password needs to contain at least one special character." : "Kodeord skal indeholde mindst et special tegn.",
    "Password needs to contain at least one lower and one upper case character." : "Kodeord skal mindst indeholde et lille bogstav og et stort bogstav ",
    "Password policy" : "Kodeord politik",
    "Allows admins to configure a password policy" : "Tillad en administrator at fastsætte en politik for adgsngskoder",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Tillad en administrator af fastsætte krav til adgangskoder, f.eks. at sætte en mindstelængde",
    "Saved" : "Gemt",
    "Minimum password length" : "Minimumslængde på adgangskode",
    "Forbid common passwords" : "Forbyd almindelige kodeord",
    "Enforce upper and lower case characters" : "Tving små og store bogstaver",
    "Enforce numeric characters" : "Tving tal",
    "Enforce special characters" : "Tving special tegn",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Kontroller adgangskoden op imod listen over kompromitterede adgangskoder i haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Dette check danner et krypteret kendetegn af adgangskoden og sender de første 4 tegn af dette kendetegn til haveibeenpwned.com's API for at modtage en liste med alle kendetegn, der starter med disse tegn. Derefter checker det, om adgsngskodekendetegnet findes i Nextclud-installationen.",
    "Unknown error" : "Ukendt fejl",
    "Password needs to be at least %s characters long" : "Kodeord skal mindst være %s tegn lang"
},
"nplurals=2; plural=(n != 1);");
